/* ppm.cpp */
/*
* This program reads/writes image in the format of PPM.
*
* Copyright (c) 2007-2010, The Chinese University of Hong Kong
* All rights reserved.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*  * Redistributions of source code must retain the above copyright
*    notice and publication information, this list of conditions and 
*    the following disclaimer.
*  * Redistributions in binary form must reproduce the above copyright
*    notice and publication information, this list of conditions and 
*    the following disclaimer in the documentation and/or other 
*    materials provided with the distribution.
*  * Neither the name of The Chinese University of Hong Kong nor the
*    names of its contributors may be used to endorse or promote products
*    derived from this software without specific prior written permission.
* 
* THIS SOFTWARE IS PROVIDED BY THE CHINESE UNIVERSITY OF HONG KONG
* ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
* CHINESE UNIVERSITY OF HONG KONG BE LIABLE FOR ANY DIRECT, INDIRECT, 
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
* CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
* LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
* ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
* POSSIBILITY OF SUCH DAMAGE.
*
*/

#include <stdio.h>
#include <string.h>
#include "ppm.h"


void read_ppm(const char *file, unsigned char * pimg)
{
	FILE *fp = fopen(file,"rb");
	if ( fp == NULL ) return;
	char buff[128];

	fgets(buff, 128, fp);
	while(buff[0] == '#') fgets(buff, 128, fp);
	if(strncmp(buff, "P6", 2))
	{ fclose(fp); return; }

	fgets(buff, 128, fp);
	while(buff[0] == '#') fgets(buff, 128, fp);
    
	int w, h;
	sscanf(buff, "%d %d", &w, &h);
    
	fgets(buff, 128, fp);
	while(buff[0] == '#') fgets(buff, 128, fp);

	fread(pimg, 1, w * h * 3, fp);
}

void get_ppm_size(const char *filename, int& w, int& h)
{
  FILE *fp = fopen(filename,"rb");
  if ( fp == NULL ) return;
  char buff[128];

  fgets(buff, 128, fp);
  while(buff[0] == '#') fgets(buff, 128, fp);
  if(strncmp(buff, "P6", 2))
    { fclose(fp); return; }

  fgets(buff, 128, fp);
  while(buff[0] == '#') fgets(buff, 128, fp);
        
  sscanf(buff, "%d %d", &w, &h);
        
  fclose(fp);
}

void write_ppm(const char*filename, unsigned char*img, int h, int w)
{
	FILE *fp = fopen(filename,"wb");
  
	fprintf(fp, "P6\n");
	fprintf(fp, "%d %d\n", w, h);
	fprintf(fp, "255\n");	
	
	fwrite(img, h*w*3, 1, fp);
	fclose(fp);
}


